@@ -118,11 +118,9 @@ qqcomp <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, main, x
   if(missing(ylim))
     ylim <- range(mydata)       
   
-  
-  
-  if(plotstyle == "graphics") {
+  if(plotstyle == "graphics") 
+  {
     ######## plot if plotstyle=='graphics' ########
-    
     # main plot
     if(!largedata)
       resquant <- plot(fittedquant[,1], sdata, main=main, xlab=xlab, ylab=ylab, log=logxy,
@@ -162,12 +160,13 @@ qqcomp <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, main, x
       else
         legend(x=xlegend, y=ylegend, bty="n", legend=legendtext, col=fitcol, lty = fitpch, lwd = fitlwd, ...)  
     }
-    invisible()
+    return(invisible(list(obs = sdata, quantiles = fittedquant)))
     
-  } else if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  } else if (!requireNamespace("ggplot2", quietly = TRUE)) 
+  {
     stop("ggplot2 needed for this function to work with plotstyle = 'ggplot'. Please install it", call. = FALSE)
-    
-  } else {
+  } else 
+  {
     ######## plot if plotstyle=='ggplot' ########
     
     # recode the legend position according to available positions in ggplot2
@@ -196,12 +195,12 @@ qqcomp <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, main, x
     }
     
     ggqqcomp <-
-      ggplot2::ggplot(data = fittedquant, ggplot2::aes_(quote(values), quote(sdata), group = quote(ind), colour = quote(ind), shape = quote(ind), size = quote(ind))) +
+      ggplot2::ggplot(data = fittedquant, ggplot2::aes(.data$values, .data$sdata, group = .data$ind, colour = .data$ind, shape = .data$ind, size = .data$ind)) +
       ggplot2::xlab(xlab) +
       ggplot2::ylab(ylab) +
       ggplot2::ggtitle(main) +
       ggplot2::coord_cartesian(xlim = c(xlim[1], xlim[2]), ylim = c(ylim[1], ylim[2])) +
-      {if(!largedata) ggplot2::geom_point() else ggplot2::geom_line(ggplot2::aes_(linetype = quote(ind), size = quote(ind)))} +
+      {if(!largedata) ggplot2::geom_point() else ggplot2::geom_line(ggplot2::aes(linetype = .data$ind, size = .data$ind))} +
       
       {if(addlegend) ggplot2::theme(legend.position = c(xlegend, ylegend), plot.title = ggplot2::element_text(hjust = 0.5)) else ggplot2::theme(legend.position = "none", plot.title = ggplot2::element_text(hjust = 0.5))} +
       ggplot2::scale_color_manual(values = fitcol, labels = legendtext) +
