@@ -1,12 +1,9 @@
-library(fitdistrplus)
-
+require("fitdistrplus")
 
 computegetparam <- fitdistrplus:::computegetparam
 
-
 computegetparam(names(formals(dgamma)))
 computegetparam(names(formals(pgamma)))
 computegetparam(names(formals(qgamma)))
 
-
 computegetparam(names(formals(dnbinom)))
